<?php
/*
* 2007-2014 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2014 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_'))
	exit;

class StColorName extends Module
{
    private $_html = '';
    public $fields_form;
    public $fields_value;
    private $_prefix_st = 'ST_COLOR_NAME_';
    public $validation_errors = array();
    public $theme_name = '';
    protected static $selectors = array(
        'lable_selector' => array(
            'classic' => '.control-label',
            'warehouse' => '.form-control-label',
        ),
        'attr_selector' => array(
            'classic' => '.product-variants-item',
        ),
        'color_selector' => array(
            'classic' => '.product-variants .input-color',
        ),
        'tpl' => array(
            'classic' => ' - <span class="st_color_name">***</span>',
        ),
    );
	function __construct()
	{
		$this->name           = 'stcolorname';
		$this->tab            = 'front_office_features';
		$this->version        = '1.0.1';
		$this->author         = 'SUNNYTOO.COM';
		$this->need_instance  = 0;
		$this->bootstrap 	  = true;
		parent::__construct();

		$this->displayName = $this->l('Color name');
		$this->description = $this->l('Show the name of selcted color out on the product page.');
	}

	function install()
	{
        $this->theme_name = Tools::strtolower(Context::getContext()->shop->theme->getName());
        $parent_theme_name = Tools::strtolower(Context::getContext()->shop->theme->get("parent",""));
        if(in_array($parent_theme_name, array('panda','transformer','warehouse','alysum')))
            $this->theme_name = $parent_theme_name;
        
		if (!parent::install() 
            || !Configuration::updateValue($this->_prefix_st.'LABLE_SELECTOR', $this->getSelector('lable_selector'))
            || !Configuration::updateValue($this->_prefix_st.'COLOR_SELECTOR', $this->getSelector('color_selector'))
            || !Configuration::updateValue($this->_prefix_st.'ATTR_SELECTOR', $this->getSelector('attr_selector'))
            || !Configuration::updateValue($this->_prefix_st.'TPL', $this->getSelector('tpl'), true)
            || !Configuration::updateValue($this->_prefix_st.'NAME_COLOR', '')
            || !Configuration::updateValue($this->_prefix_st.'NAME_SIZE', 0)
            || !Configuration::updateValue($this->_prefix_st.'CUSTOM_CSS', '')
            || !$this->registerHook('displayHeader')
        )
			return false;

		return true;
	}
    public function getSelector($key){
        return array_key_exists($this->theme_name, self::$selectors[$key]) ? self::$selectors[$key][$this->theme_name] : self::$selectors[$key]['classic'];
    }

    public function getContent()
    {
        $this->context->controller->addCSS($this->_path.'views/css/admin.css');
        $this->initFieldsForm();
        if (isset($_POST['savestcolorname']))
        {
            if (isset($_POST['custom_css']) && $_POST['custom_css'])
                $_POST['custom_css'] = str_replace('\\', '¤', $_POST['custom_css']);

            foreach($this->fields_form as $form)
                foreach($form['form']['input'] as $field)
                    if(isset($field['validation']))
                    {
                        $ishtml = ($field['validation']=='isAnything') ? true : false;
                        $errors = array();       
                        $value = Tools::getValue($field['name']);
                        if (isset($field['required']) && $field['required'] && $value==false && (string)$value != '0')
                                $errors[] = sprintf(Tools::displayError('Field "%s" is required.'), $field['label']);
                        elseif($value)
                        {
                            $field_validation = $field['validation'];
                            if (!Validate::$field_validation($value))
                                $errors[] = sprintf(Tools::displayError('Field "%s" is invalid.'), $field['label']);
                        }
                        // Set default value
                        if ($value === false && isset($field['default_value']))
                            $value = $field['default_value'];
                        
                        if(count($errors))
                        {
                            $this->validation_errors = array_merge($this->validation_errors, $errors);
                        }
                        elseif($value==false)
                        {
                            switch($field['validation'])
                            {
                                case 'isUnsignedId':
                                case 'isUnsignedInt':
                                case 'isInt':
                                case 'isBool':
                                    $value = 0;
                                break;
                                default:
                                    $value = '';
                                break;
                            }
                            Configuration::updateValue($this->_prefix_st.strtoupper($field['name']), $value);
                        }
                        else
                            Configuration::updateValue($this->_prefix_st.strtoupper($field['name']), $value, $ishtml);
                    }

            if(count($this->validation_errors))
                $this->_html .= $this->displayError(implode('<br/>',$this->validation_errors));
            else 
                $this->_html .= $this->displayConfirmation($this->l('Settings updated'));

            $this->_clearCache('*');
        }

        $helper = $this->initForm();
        
        return $this->_html.$helper->generateForm($this->fields_form).'<div class="alert alert-info">This free module was created by <a href="https://www.sunnytoo.com" target="_blank">ST-THEMES</a>, it\'s not allow to sell it, it\'s also not allow to create new modules based on this one. Check more <a href="https://www.sunnytoo.com/blogs?term=743&orderby=date&order=desc" target="_blank">free modules</a>, <a href="https://www.sunnytoo.com/product-category/prestashop-modules" target="_blank">advanced paid modules</a> and <a href="https://www.sunnytoo.com/product-category/prestashop-themes" target="_blank">themes(transformer theme and panda  theme)</a> created by <a href="https://www.sunnytoo.com" target="_blank">ST-THEMES</a>.</div>';
    }

    protected function initFieldsForm()
    {
        $groups_arr = array();
        $all_groups = AttributeGroup::getAttributesGroups($this->context->language->id);
        foreach ($all_groups as $group){
            $groups_arr[] = array(
                'id' => $group['id_attribute_group'],
                'name' => $group['name'],
                'val' => $group['id_attribute_group'],
            );
        }
        $this->fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->displayName,
                'icon' => 'icon-cogs'
            ),
            'input' => array( 
                array(
                    'type' => 'text',
                    'label' => $this->l('Color label selector:'),
                    'name' => 'lable_selector',
                    'validation' => 'isAnything',
                    'desc' => $this->l('Color name will be shown beside color label.'),
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Color input selector:'),
                    'name' => 'color_selector',
                    'validation' => 'isAnything',
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Attribute group selector:'),
                    'name' => 'attr_selector',
                    'validation' => 'isAnything',
                ),
                 array(
                    'type' => 'color',
                    'label' => $this->l('Color name color:'),
                    'name' => 'name_color',
                    'class' => 'color',
                    'size' => 20,
                    'validation' => 'isColor',
                 ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Color name size:'),
                    'name' => 'name_size',
                    'prefix' => 'px',
                    'class' => 'fixed-width-lg',
                    'validation' => 'isNullOrUnsignedId',
                ),
                array(
                    'type' => 'textarea',
                    'label' => $this->l('HTML template:'),
                    'name' => 'tpl',
                    'cols' => 60,
                    'rows' => 5,
                    'desc' => array(
                        $this->l('*** will be replaced with color name.'),
                        $this->l('Color name much be wrapped with a tag which contains a classname "st_color_name".')
                    ),
                    'validation' => 'isAnything',
                ),
                array(
                    'type' => 'textarea',
                    'label' => $this->l('Custom CSS Code:'),
                    'name' => 'custom_css',
                    'cols' => 60,
                    'rows' => 10,
                    'desc' => $this->l('Put CSS code here without wrapping them in STYLE tag'),
                    'validation' => 'isAnything',
                ),
            ),
            'submit' => array(
                'title' => $this->l('   Save   ')
            )
        );
    }
    protected function initForm()
    {
        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table =  $this->table;
        $helper->module = $this;
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'savestcolorname';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );

        return $helper;
    }
    
    private function getConfigFieldsValues()
    {
        $fields_values = array(
            'lable_selector' => Configuration::get($this->_prefix_st.'LABLE_SELECTOR'),
            'color_selector' => Configuration::get($this->_prefix_st.'COLOR_SELECTOR'),
            'attr_selector' => Configuration::get($this->_prefix_st.'ATTR_SELECTOR'),
            'tpl' => Configuration::get($this->_prefix_st.'TPL'),
            'name_color' => Configuration::get($this->_prefix_st.'NAME_COLOR'),
            'name_size' => Configuration::get($this->_prefix_st.'NAME_SIZE'),
            'custom_css' => str_replace('¤', '\\', Configuration::get($this->_prefix_st.'CUSTOM_CSS')),
        );
        
        if ($fields_values['tpl'])
            $fields_values['tpl'] = html_entity_decode($fields_values['tpl']);

        return $fields_values;
    }
    public function hookDisplayHeader($params)
    {
        $this->context->controller->addJS($this->_path.'views/js/front.js');

        $tpl = Configuration::get($this->_prefix_st.'TPL');
        Media::addJsDef(array('stcolorname' => array(
            'tpl' => $tpl ? html_entity_decode($tpl) : '',
            'lable_selector' => Configuration::get($this->_prefix_st.'LABLE_SELECTOR'),
            'color_selector' => Configuration::get($this->_prefix_st.'COLOR_SELECTOR'),
            'attr_selector' => Configuration::get($this->_prefix_st.'ATTR_SELECTOR'),
        )));

        $template_file = 'module:'.$this->name.'/views/templates/hook/header.tpl';
        if (!$this->isCached($template_file, $this->getCacheId())) {
            $css = '';
            if($name_color = Configuration::get($this->_prefix_st.'NAME_COLOR'))
                $css .= '.st_color_name{color:'.$name_color.';}';
            if($name_size = Configuration::get($this->_prefix_st.'NAME_SIZE'))
                $css .= '.st_color_name{font-size:'.$name_size.'px;}';

            if ($custom_css = Configuration::get($this->_prefix_st.'CUSTOM_CSS'))
                $css .= html_entity_decode(str_replace('¤', '\\', $custom_css));

            $this->context->smarty->assign('custom_css', $css);
        }

        return $this->fetch($template_file, $this->getCacheId());
    }
}